@@ -21,6 +21,7 @@
 import re
 import os
 import subprocess
+
 from oem_config.filteredcommand import FilteredCommand
 from oem_config import keyboard_names
 
@@ -105,7 +106,7 @@ class ConsoleSetup(FilteredCommand):
         and options."""
 
         if layout in ('am', 'ara', 'ben', 'bd', 'bg', 'bt', 'by', 'deva', 'ge',
-                      'gh', 'gr', 'guj', 'guru', 'il', 'in', 'ir', 'iku', 'jp',
+                      'gh', 'gr', 'guj', 'guru', 'il', 'in', 'ir', 'iku',
                       'kan', 'kh', 'la', 'lao', 'lk', 'mk', 'mm', 'mn', 'mv',
                       'mal', 'ori', 'pk', 'ru', 'scc', 'sy', 'syr', 'tel',
                       'th', 'tj', 'tam', 'ua', 'uz'):
@@ -118,6 +119,16 @@ class ConsoleSetup(FilteredCommand):
             else:
                 latin = False
                 real_layout = 'cs,cs'
+        elif layout == 'jp':
+            if variant == 'latin':
+                latin = True
+                real_layout = layout
+            else:
+                latin = False
+                real_layout = 'jp,jp'
+        elif layout == 'lt':
+            latin = False
+            real_layout = 'lt,lt'
         else:
             latin = True
             real_layout = layout
@@ -131,6 +142,13 @@ class ConsoleSetup(FilteredCommand):
                 real_variant = 'latinalternatequotes,%s' % variant
             else:
                 real_variant = 'latin,%s' % variant
+        elif real_layout == 'jp,jp':
+            real_variant = 'latin,%s' % variant
+        elif real_layout == 'lt,lt':
+            if variant == 'us':
+                real_variant = 'us,'
+            else:
+                real_variant = '%s,us' % variant
         else:
             real_variant = ',%s' % variant
 
